<?php

class OfertasModel
{
    private $tu_conexion;

    public function __construct($conexion)
    {
        $this->tu_conexion = $conexion;
    }

    public function obtenerCantidadOfertas()
    {
        $query = "SELECT COUNT(*) AS cantidad FROM ofertas_laborales";
        $result = mysqli_query($this->tu_conexion, $query);

        if (!$result) {
            die("Error en la consulta: " . mysqli_error($this->tu_conexion));
        }

        $row = mysqli_fetch_assoc($result);

        return $row['cantidad'];
    }

    
    //listar ofertas

    public function obtenerTodasLasOfertas()
    {
        $query = "SELECT o.id_oferta, o.titulo, o.descripcion, o.fecha_publicacion, o.fecha_limite, 
                         tc.nombre_tipo_contrato AS Contrato, e.nombre_empresa AS Empresa, pe.nombre_programa AS Programa, o.tipo_oferta,o.fecha_actualizacion
                  FROM ofertas_laborales o
                  JOIN tipos_contrato tc ON o.id_tipo_contrato = tc.id_tipo_contrato
                  JOIN empresas e ON o.id_empresa = e.id_empresa
                  LEFT JOIN programas_estudio pe ON o.id_programa = pe.id_programa
                  ORDER BY o.fecha_actualizacion DESC";

        $result = mysqli_query($this->tu_conexion, $query);

        if (!$result) {
            die("Error en la consulta: " . mysqli_error($this->tu_conexion));
        }

        $ofertas = [];
        while ($row = mysqli_fetch_assoc($result)) {
            $ofertas[] = $row;
        }

        return $ofertas;
    }

    //obtener oferta detallada
    public function obtenerDetallesOferta($ofertaId)
        {
            $query = "SELECT o.id_oferta, o.titulo, o.descripcion, o.fecha_publicacion, o.fecha_limite, tc.nombre_tipo_contrato as Contrato, e.nombre_empresa as Empresa, pe.nombre_programa as Programa ,
            o.tipo_oferta, o.correo_oferta, o.lugar_oferta, o.telefono_oferta FROM ofertas_laborales o
            INNER JOIN tipos_contrato tc ON tc.id_tipo_contrato = o.id_tipo_contrato
            INNER JOIN empresas e ON e.id_empresa = o.id_empresa
            LEFT JOIN programas_estudio pe ON pe.id_programa = o.id_programa WHERE o.id_oferta = ?";
        
            $stmt = mysqli_prepare($this->tu_conexion, $query);
        
            if (!$stmt) {
                die("Error en la consulta preparada: " . mysqli_error($this->tu_conexion));
            }
        
            mysqli_stmt_bind_param($stmt, "i", $ofertaId);
            $result_execute = mysqli_stmt_execute($stmt);
        
            if ($result_execute === false) {
                // Manejar error en la ejecución de la consulta
                die("Error al ejecutar la consulta: " . mysqli_error($this->tu_conexion));
            }
        
            $result = mysqli_stmt_get_result($stmt);
        
            if ($result !== false) {
                // Verificar si se obtuvieron resultados
                if ($detallesOferta = mysqli_fetch_assoc($result)) {
                    // Cerrar la consulta preparada
                    mysqli_stmt_close($stmt);
                    return $detallesOferta;
                } else {
                    // Oferta no encontrada
                    die("La oferta con ID $ofertaId no existe.");
                }
            } else {
                // Manejar error al obtener el resultado
                die("Error al obtener resultados: " . mysqli_error($this->tu_conexion));
            }
        }
    
    
    //agregar ofertar
    public function agregarOferta($datosOferta) {
        $query = "INSERT INTO ofertas_laborales (titulo, descripcion, fecha_publicacion, fecha_limite, id_empresa, id_programa, id_tipo_contrato, lugar,tipo_oferta,correo_oferta,lugar_oferta,telefono_oferta) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = mysqli_prepare($this->tu_conexion, $query);
        mysqli_stmt_bind_param($stmt, "ssssiiisssss", $datosOferta['titulo'], $datosOferta['descripcion'], $datosOferta['fecha_publicacion'], $datosOferta['fecha_limite'], $datosOferta['id_empresa'], $datosOferta['id_programa'], $datosOferta['id_tipo_contrato'], $datosOferta['lugar'], $datosOferta['tipo_oferta'], $datosOferta['correo_oferta'], $datosOferta['lugar_oferta'], $datosOferta['telefono_oferta']);

        $resultado = mysqli_stmt_execute($stmt);

        mysqli_stmt_close($stmt);

        return $resultado;
    }

    // Mostrar ofertas del estudiante
    
    public function obtenerOfertasPostuladas($id_usuario)
        {
            $query = "SELECT p.id_postulacion, o.id_oferta, o.titulo, p.fecha_postulacion, e.nombre_empresa, e.direccion_empresa, e.telefono_empresa 
                    FROM ofertas_laborales o 
                    INNER JOIN postulaciones p ON o.id_oferta = p.id_oferta 
                    INNER JOIN empresas e ON e.id_empresa = o.id_empresa
                    WHERE p.id_usuario = ?";
            
            // Preparar la consulta
            $stmt = mysqli_prepare($this->tu_conexion, $query);
        
            // Verificar si la preparación de la consulta fue exitosa
            if (!$stmt) {
                die("Error en la preparación de la consulta: " . mysqli_error($this->tu_conexion));
            }
        
            // Vincular el parámetro
            mysqli_stmt_bind_param($stmt, "i", $id_usuario);
        
            // Ejecutar la consulta
            $result_execute = mysqli_stmt_execute($stmt);
        
            // Verificar si la ejecución fue exitosa
            if ($result_execute === false) {
                // Manejar error en la ejecución de la consulta
                die("Error al ejecutar la consulta: " . mysqli_error($this->tu_conexion));
            }
        
            // Obtener el resultado
            $result = mysqli_stmt_get_result($stmt);
        
            // Verificar si se obtuvo el resultado
            if ($result !== false) {
                // Obtener detalles de la oferta
                $postulaciones = mysqli_fetch_all($result, MYSQLI_ASSOC);
        
                // Liberar el resultado y cerrar la consulta preparada
                mysqli_free_result($result);
                mysqli_stmt_close($stmt);
            } else {
                // Manejar error al obtener el resultado
                die("Error al obtener resultados: " . mysqli_error($this->tu_conexion));
            }
        
            return $postulaciones;
        }
   
    
    
   
}

?>
